@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package Moose::Meta::Attribute::Custom::Trait::Indexed;
 BEGIN {
-  $Moose::Meta::Attribute::Custom::Trait::Indexed::VERSION = '1.0.0';
+  $Moose::Meta::Attribute::Custom::Trait::Indexed::VERSION = '1.0.1';
 }
 
 # ABSTRACT: Registration Node for the Indexed Trait.
@@ -26,7 +26,7 @@ Moose::Meta::Attribute::Custom::Trait::Indexed - Registration Node for the Index
 
 =head1 VERSION
 
-version 1.0.0
+version 1.0.1
 
 =head1 METHODS
 
@@ -34,10 +34,20 @@ version 1.0.0
 
 Associates the Indexed trait with MX::AI
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 Kent Fredric <kentnl@cpan.org>
 
+=item *
+
+Jesse Luehrs <doy@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2011 by Kent Fredric.
